Spec-Zone.ru › Linux man pages

lpinfo(8) — Справочная страница Linux

lpinfo(8)                      Apple Inc.                      lpinfo(8)

ИМЯ

       lpinfo - show available devices or drivers (deprecated)

СИНТАКСИС

       lpinfo [ -E ] [ -h server[:port] ] [ -l ] [ --device-id device-
       id-string ] [ --exclude-schemes scheme-list ] [ --include-schemes
       scheme-list ] [ --language locale ] [ --make-and-model name ] [
       --product name ] -m
       lpinfo [ -E ] [ -h server[:port] ] [ -l ] [ --exclude-schemes
       scheme-list ] [ --include-schemes scheme-list ] [ --timeout
       seconds ] -v

ОПИСАНИЕ

       lpinfo lists the available devices or drivers known to the CUPS
       server.  The first form (-m) lists the available drivers, while
       the second form (-v) lists the available devices.

ПАРАМЕТРЫ

       lpinfo accepts the following options:

       -E   Forces encryption when connecting to the server.

       -h server[:port]
            Selects an alternate server.

       -l   Shows a "long" listing of devices or drivers.

       --device-id device-id-string
            Specifies the IEEE-1284 device ID to match when listing
            drivers with the -m option.

       --exclude-schemes scheme-list
            Specifies a comma-delimited list of device or PPD schemes
            that should be excluded from the results.  Static PPD files
            use the "file" scheme.

       --include-schemes scheme-list
            Specifies a comma-delimited list of device or PPD schemes
            that should be included in the results.  Static PPD files
            use the "file" scheme.

       --language locale
            Specifies the language to match when listing drivers with
            the -m option.

       --make-and-model name
            Specifies the make and model to match when listing drivers
            with the -m option.

       --product name
            Specifies the product to match when listing drivers with the
            -m option.

       --timeout seconds
            Specifies the timeout when listing devices with the -v
            option.

СООТВЕТСТВИЕ

       The lpinfo command is unique to CUPS.

ПРИМЕРЫ

       List all devices:

           lpinfo -v

       List all drivers:

           lpinfo -m

       List drivers matching "HP LaserJet":

           lpinfo --make-and-model "HP LaserJet" -m

ЗАМЕЧАНИЯ

       CUPS printer drivers and backends are deprecated and will no
       longer be supported in a future feature release of CUPS.
       Printers that do not support IPP can be supported using
       applications such as ippeveprinter(1).

СМОТРИТЕ ТАКЖЕ

       lpadmin(8), CUPS Online Help (http://localhost:631/help)

АВТОРСКИЕ ПРАВА

       Copyright © 2007-2019 by Apple Inc.

КОЛОФОН

       This page is part of the CUPS (a standards-based, open source
       printing system) project.  Information about the project can be
       found at ⟨http://www.cups.org/⟩.  If you have a bug report for
       this manual page, see ⟨http://www.cups.org/⟩.  This page was
       obtained from the project's upstream Git repository
       ⟨https://github.com/apple/cups⟩ on 2024-06-14.  (At that time,
       the date of the most recent commit that was found in the
       repository was 2023-10-27.)  If you discover any rendering
       problems in this HTML version of the page, or you believe there
       is a better or more up-to-date source for the page, or you have
       corrections or improvements to the information in this COLOPHON
       (which is not part of the original manual page), send a mail to
       man-pages@man7.org

26 April 2019                     CUPS                         lpinfo(8)

Страницы, которые ссылаются на эту страницу: cups(1), backend(7), cups-snmp(8), lpadmin(8)


...
https://man7.org/linux/man-pages/man8/lpinfo.8.html

Spec-Zone.ru

Настройки Оффлайн Что нового Помощь О нас
Spec-Zone .ru
спецификации, руководства, описания, API